import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;

/**
 * Magnet is the small magnet that runs in the etchAsketch.
 * It does not draw on the screen.  It only represents the magnet on the screen.
 * 
 * @author Jules Bonin-Ducharme
 * @version 1.1
 */
public class Magnet  extends Actor
{
    private Screen screen;
    private int oldX;
    private int oldY;
    private int newX;
    private int newY;
    
    /**
     * Construct a Magnet with a small image in the specified screen.
     */
    public Magnet(Screen screen)
    {
        this.screen = screen;
        GreenfootImage magnet = new GreenfootImage(5,2);
        magnet.setColor(java.awt.Color.white);
        magnet.fill();
        setImage(magnet);
    }
    
    /**
     * Act - do whatever the Magnet wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        move(); 
        changeColor();
        draw();
    }
    
    /**
     * Move the magnet around the screen.
     */
    public void move()
    {
        oldX = newX;
        oldY = newY;
        
        newX = getX();
        newY = getY();
        
        if (Greenfoot.isKeyDown("up") && newY > 52)
            newY--;
        if (Greenfoot.isKeyDown("down") && newY < 398)
            newY++;
        if (Greenfoot.isKeyDown("left") && newX > 54)
            newX--;
        if (Greenfoot.isKeyDown("right") && newX < 546)
            newX++;
         
        setLocation(newX, newY);
    }
    
    /**
     * Draw a line under the magnet on the screen.
     */
    public void draw()
    {
        screen.getImage().drawLine(oldX - 50, oldY - 50, newX - 50, newY - 50);
    }
    
    /**
     * Setting the color of the drawing magnet.
     */
    public void changeColor()
    {
        String key = Greenfoot.getKey();
        if (key != null)
        {
            if (key.equals("1"))
                screen.getImage().setColor(Color.black);
    
            if (key.equals("2"))
                screen.getImage().setColor(Color.red);

            if (key.equals("3"))
                screen.getImage().setColor(Color.blue);
                
            if (key.equals("4"))
                screen.getImage().setColor(Color.yellow);

            if (key.equals("5"))
                screen.getImage().setColor(Color.orange);
                
        }
        
    }
    
    /**
     * Called when the world added the magnet.
     */
    protected void addedToWorld(World world)
    {
        oldX = newX = getX();
        oldY = newY = getY();
    }
}
